<?php

namespace WC_Integration_NettiX\Plugin;

class Activation {

	private Database_Settings $db_settings;

	public function __construct() {
		$this->db_settings = new Database_Settings();
	}

	public function do_activation() {
		$this->create_db_tables();
		$this->create_product_cats();

		/** Migration will be removed in future versions */
		$this->migrate_from_proprietary_plugin();
	}

	private function create_db_tables() {
		$this->create_table_nettix_product_map();
		$this->create_table_nettix_product_image_map();
	}

	private function create_table_nettix_product_map() {
		global $wpdb;

		$sql = "CREATE TABLE " . $this->db_settings->table_product_map . " (\n";
		$sql .= "  id int NOT NULL AUTO_INCREMENT,\n";
		$sql .= "  post_id int,\n";
		$sql .= "  nettix_id int,\n";
		$sql .= "  PRIMARY KEY  (id),\n";
		$sql .= "  KEY post_id (post_id),\n";
		$sql .= "  KEY nettix_id (nettix_id)\n";
		$sql .= ") " . $wpdb->get_charset_collate() . ";";

		dbDelta( $sql );
	}

	private function create_table_nettix_product_image_map() {
		global $wpdb;

		$sql = "CREATE TABLE " . $this->db_settings->table_product_image_map . " (\n";
		$sql .= "  id int NOT NULL AUTO_INCREMENT,\n";
		$sql .= "  post_id int,\n";
		$sql .= "  nettix_id int,\n";
		$sql .= "  image_id int,\n";
		$sql .= "  image_filename varchar(192),\n";
		$sql .= "  PRIMARY KEY  (id),\n";
		$sql .= "  KEY post_id (post_id),\n";
		$sql .= "  KEY nettix_id (nettix_id),\n";
		$sql .= "  KEY image_id (image_id),\n";
		$sql .= "  KEY image_filename (image_filename)\n";
		$sql .= ") " . $wpdb->get_charset_collate() . ";";

		dbDelta( $sql );
	}

	private function create_product_cats() {
		if ( ! term_exists( 'NettiMoto', 'product_cat' ) ) {
			wp_insert_term( 'NettiMoto',
				'product_cat',
				[
					'slug'        => 'nettimoto',
					'description' => __( 'Product category for motor bike ads imported from Nettimoto by NettiX integration',
						'wc-integration-to-nettix' )
				] );
		}
		if ( ! term_exists( 'NettiVene', 'product_cat' ) ) {
			wp_insert_term( 'NettiVene',
				'product_cat',
				[
					'slug'        => 'nettivene',
					'description' => __( 'Product category for boat ads imported from Nettivene by NettiX integration',
						'wc-integration-to-nettix' )
				] );
		}
		if ( ! term_exists( 'NettiAuto', 'product_cat' ) ) {
			wp_insert_term( 'NettiAuto',
				'product_cat',
				[
					'slug'        => 'nettiauto',
					'description' => __( 'Product category for car ads imported from Nettiauto by NettiX integration',
						'wc-integration-to-nettix' )
				] );
		}
	}

	/**
	 * Migrate data from proprietary plugin if that plugin is installed.
	 * Very limited amount of installations exists and these methods will be removed in future versions.
	 *
	 * @return void
	 */
	private function migrate_from_proprietary_plugin(): void {
		$proprietary_plugin_path = trailingslashit( WP_PLUGIN_DIR ) . 'nettix-api-client/nettix-api-client.php';

		if ( in_array( $proprietary_plugin_path, wp_get_active_and_valid_plugins() ) ) {
			$this->remove_proprietary_plugin_cron_scheduling();
			$this->migrate_product_map();
			$this->migrate_product_image_map();
		}
	}

	private function remove_proprietary_plugin_cron_scheduling(): void {
		$timestamp = wp_next_scheduled( 'nxac_cron_hook' );
		wp_unschedule_event( $timestamp, 'nxac_cron_hook' );
	}

	private function migrate_product_map(): void {
		global $wpdb;

		$product_map_table_name = $wpdb->prefix . "nxac_product_map";

		$query  = "SELECT * FROM " . $product_map_table_name . " ORDER BY id ASC";
		$result = $wpdb->get_results( $query, ARRAY_A );

		foreach ( $result as $res ) {
			$wpdb->insert( $this->db_settings->table_product_map, [
				'id'        => $res['id'],
				'post_id'   => $res['postId'],
				'nettix_id' => $res['nettixId'],
			] );
		}
	}

	private function migrate_product_image_map(): void {
		global $wpdb;

		$product_image_map_table_name = $wpdb->prefix . "nxac_product_image_map";

		$query  = "SELECT * FROM " . $product_image_map_table_name . " ORDER BY id ASC";
		$result = $wpdb->get_results( $query, ARRAY_A );

		foreach ( $result as $res ) {
			$wpdb->insert( $this->db_settings->table_product_image_map, [
				'id'             => $res['id'],
				'post_id'        => $res['postId'],
				'nettix_id'      => $res['nettixId'],
				'image_id'       => $res['imageId'],
				'image_filename' => $res['imageFilename'],
			] );
		}
	}
}