<?php

if ( ! class_exists( 'Wc_Integration_NettiX_Integration' ) ) {
	class WC_Integration_NettiX_Integration extends WC_Integration {
		/**
		 * Init and hook in the integration.
		 */
		public function __construct() {
			global $woocommerce;
			$this->id                 = 'wc-integration-to-nettix';
			$this->method_title       = __( 'Integration to NettiX', 'wc-integration-to-nettix' );
			$this->method_description = __( 'Integration between WooCommerce and NettiX.',
				'wc-integration-to-nettix' );
			// Load the settings.
			$this->init_form_fields();
			$this->init_settings();
			// Define user set variables.
			$this->client_id     = $this->get_option( 'nettix_client_id' );
			$this->client_secret = $this->get_option( 'nettix_secret_id' );
			$this->user_ids      = $this->get_option( 'nettix_user_ids' );
			$this->service_boat  = $this->get_option( 'nettix_service_boat' );
			$this->service_car   = $this->get_option( 'nettix_service_car' );
			$this->service_bike  = $this->get_option( 'nettix_service_bike' );
			// Actions.
			add_action( 'woocommerce_update_options_integration_' . $this->id, [ $this, 'process_admin_options' ] );
		}

		/**
		 * Initialize integration settings form fields.
		 */
		public function init_form_fields() {
			$this->form_fields = [
				'nettix_client_id'    => [
					'title'       => __( 'Client ID', 'wc-integration-to-nettix' ),
					'type'        => 'text',
					'description' => __( 'Enter with your Client ID provided by NettiX',
						'wc-integration-to-nettix' ),
					'desc_tip'    => true,
					'default'     => ''
				],
				'nettix_secret_id'    => [
					'title'       => __( 'Client Secret', 'wc-integration-to-nettix' ),
					'type'        => 'password',
					'description' => __( 'Enter with your Client Secret provided by NettiX',
						'wc-integration-to-nettix' ),
					'desc_tip'    => true,
					'default'     => ''
				],
				'nettix_user_ids'     => [
					'title'       => __( 'User IDs (store IDs)', 'wc-integration-to-nettix' ),
					'type'        => 'text',
					'description' => __( 'Comma separated list of user IDs (numerical store IDs) provided by NettiX',
						'wc-integration-to-nettix' ),
					'desc_tip'    => true,
					'default'     => ''
				],
				'nettix_service_car'  => [
					'title'       => __( 'NettiX Services', 'wc-integration-to-nettix' ),
					'type'        => 'checkbox',
					'label'       => __( 'Nettiauto', 'wc-integration-to-nettix' ),
					'default'     => 'no',
					'description' => __( 'Use NettiX service Nettiauto', 'wc-integration-to-nettix' ),
				],
				'nettix_service_bike' => [
					'type'        => 'checkbox',
					'label'       => __( 'Nettimoto', 'wc-integration-to-nettix' ),
					'default'     => 'no',
					'description' => __( 'Use NettiX service Nettimoto', 'wc-integration-to-nettix' ),
				],
				'nettix_service_boat' => [
					'type'        => 'checkbox',
					'label'       => __( 'Nettivene', 'wc-integration-to-nettix' ),
					'default'     => 'no',
					'description' => __( 'Use NettiX service Nettivene', 'wc-integration-to-nettix' ),
				],
				'nettix_test_connection_button' => [
					'type'        => 'testconnbutton',
					'label'       => __( 'Test connection', 'wc-integration-to-nettix' ),
					'default'     => '',
					'description' => __( 'Check that connection settings are correct. Testing logging-in to NettiX API.',
						'wc-integration-to-nettix' ),
					'desc_tip'    => true,
                    'custom_attributes' => [
                            'onclick' => 'testConnection()'
                    ]
				]
			];
		}

		public function generate_testconnbutton_html( $key, $data ) {
			$field    = $this->plugin_id . $this->id . '_' . $key;
			$defaults = [
				'class'             => 'button-secondary',
				'css'               => '',
				'custom_attributes' => [],
				'desc_tip'          => false,
				'description'       => '',
				'label'             => '',
			];

			$data = wp_parse_args( $data, $defaults );

			ob_start();
			?>
			<tr>
				<th scope="row" class="titledesc">
					<label for="<?php echo esc_attr( $field ); ?>"><?php echo wp_kses_post( $data['label'] ); ?></label>
					<?php echo $this->get_tooltip_html( $data ); ?>
				</th>
				<td class="forminp">
					<fieldset>
						<legend class="screen-reader-text"><span><?php echo wp_kses_post( $data['label'] ); ?></span></legend>
						<button class="<?php echo esc_attr( $data['class'] ); ?>" type="button" name="<?php echo esc_attr( $field ); ?>" id="<?php echo esc_attr( $field ); ?>" style="<?php echo esc_attr( $data['css'] ); ?>" <?php echo $this->get_custom_attribute_html( $data ); ?>><?php echo wp_kses_post( $data['label'] ); ?></button><span id="wc-nettix-integration-test-connection-spinner" class="spinner" style="float: none !important"></span><span id="wc-nettix-integration-test-connection-result"></span>
						<?php echo $this->get_description_html( $data ); ?>
					</fieldset>
				</td>
			</tr>
			<?php
			return ob_get_clean();
		}
	}
}