<?php
/**
 * Plugin Name:       Integration to NettiX for WooCommerce
 * Description:       Integration between WooCommerce and NettiX (https://almaajo.fi). Following Alma Ajo (previously NettiX) services can be used with this integration: Nettiauto, Nettimoto, and Nettivene.
 * Version:           1.0.4
 * Requires at least: 5.8
 * Requires PHP:      7.4
 * Author:            Orwokki <info@orwokki.com>
 * Author URI:        https://orwokki.com
 * Developer:         Orwokki <info@orwokki.com>
 * Developer URI:     https://orwokki.com
 * Text Domain:       wc-integration-to-nettix
 * Domain Path:       /languages
 *
 * WC requires at least: 5.0
 * WC tested up to: 7.5
 *
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * Nettiauto, Nettimoto, and Nettivene are registered trademarks of Alma Media Suomi Oy.
 * The mentioned registered trademarks are excluded from this license. Author of this plugin
 * doesn't have ANY relation with Alma Media Suomi Oy. By using this plugin user doesn't
 * get ANY rights to the mentioned registered trademarks.
 */

// If this file is called directly, abort.
if ( ( ! defined( 'WPINC' ) ) || ( ! defined( 'ABSPATH' ) ) ) {
	exit;
}

if ( ! function_exists( 'dbDelta' ) ) {
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
}

if ( ! function_exists( 'wp_get_active_network_plugins' ) ) {
	require_once( ABSPATH . 'wp-includes/ms-load.php' );
}

// Import interfaces
require_once plugin_dir_path( __FILE__ ) . 'src/classes/Cache/Cache.php';

// Import classes
require_once plugin_dir_path( __FILE__ ) . 'src/classes/Plugin/Plugin_Settings.php';
require_once plugin_dir_path( __FILE__ ) . 'src/classes/Plugin/Database_Settings.php';
require_once plugin_dir_path( __FILE__ ) . 'src/classes/Plugin/Activation.php';
require_once plugin_dir_path( __FILE__ ) . 'src/classes/Cache/File_Cache.php';
require_once plugin_dir_path( __FILE__ ) . 'src/classes/NettiX_Client/Authentication.php';
require_once plugin_dir_path( __FILE__ ) . 'src/classes/NettiX_Client/Base_Client.php';
require_once plugin_dir_path( __FILE__ ) . 'src/classes/NettiX_Client/Nettiauto_Client.php';
require_once plugin_dir_path( __FILE__ ) . 'src/classes/NettiX_Client/Nettimoto_Client.php';
require_once plugin_dir_path( __FILE__ ) . 'src/classes/NettiX_Client/Nettivene_Client.php';
require_once plugin_dir_path( __FILE__ ) . 'src/classes/Plugin/Ad_Data.php';
require_once plugin_dir_path( __FILE__ ) . 'src/classes/Plugin/Ad_Handler.php';
require_once plugin_dir_path( __FILE__ ) . 'src/classes/Plugin/Nettiauto_Ad_Handler.php';
require_once plugin_dir_path( __FILE__ ) . 'src/classes/Plugin/Nettimoto_Ad_Handler.php';
require_once plugin_dir_path( __FILE__ ) . 'src/classes/Plugin/Nettivene_Ad_Handler.php';
require_once plugin_dir_path( __FILE__ ) . 'src/classes/Plugin/Fetcher.php';
require_once plugin_dir_path( __FILE__ ) . 'src/classes/Admin/Api.php';

use WC_Integration_NettiX\Plugin\Activation;
use WC_Integration_NettiX\Plugin\Fetcher;
use WC_Integration_NettiX\Plugin\Plugin_Settings;
use WC_Integration_NettiX\Admin\Api as AdminApi;

// Test to see if WooCommerce is active (including network activated).
$plugin_path = trailingslashit( WP_PLUGIN_DIR ) . 'woocommerce/woocommerce.php';

if (
	in_array( $plugin_path, wp_get_active_and_valid_plugins() )
	|| in_array( $plugin_path, wp_get_active_network_plugins() )
) {
	function wc_integration_to_nettix_set_admin_scripts() {
		if (
			is_user_logged_in() &&
			(
				current_user_can('administrator')
				|| current_user_can('shop_manager')
			)
		) {
			wp_register_script('wc-integration-to-nettix-admin-general-functions-script', plugins_url('/js/general-functions.js', __FILE__));
			wp_enqueue_script('wc-integration-to-nettix-admin-general-functions-script');
		}
	}
	add_action("admin_enqueue_scripts", "wc_integration_to_nettix_set_admin_scripts");

	$adminApi = new AdminApi;
	add_action('wp_ajax_wc_integration_to_nettix_test_connection', [$adminApi, 'test_connection']);

	function woocommerce_integration_nettix_add_integration( $integrations ): array {
		$integrations[] = 'WC_Integration_NettiX_Integration';

		return $integrations;
	}

	function woocommerce_integration_nettix_init(): void {
		if ( class_exists( 'WC_Integration' ) ) {
			// Include our integration class.
			include_once plugin_dir_path( __FILE__ ) . 'src/classes/WC_Integration_NettiX_Integration.php';

			// Register the integration.
			add_filter( 'woocommerce_integrations', 'woocommerce_integration_nettix_add_integration' );
		}
	}

	add_action( 'plugins_loaded', 'woocommerce_integration_nettix_init' );

	$settings = new Plugin_Settings();
	$fetcher  = new Fetcher( $settings );

	add_action( 'wp_ajax_wc_integration_nettix_attach_ad_images',
		[ $fetcher, 'wc_integration_nettix_fetcher_ajax_attach_ad_images' ] );
	add_action( 'wp_ajax_nopriv_wc_integration_nettix_attach_ad_images',
		[ $fetcher, 'wc_integration_nettix_fetcher_ajax_attach_ad_images' ] );

	function woocommerce_integration_nettix_cron_events() {
		$settings = new Plugin_Settings();
		$fetcher  = new Fetcher( $settings );
		$fetcher->fetch();
	}

	add_action( 'woocommerce_integration_nettix_cron_hook', 'woocommerce_integration_nettix_cron_events' );

	function woocommerce_integration_nettix_deactivate() {
		$timestamp = wp_next_scheduled( 'woocommerce_integration_nettix_cron_hook' );
		wp_unschedule_event( $timestamp, 'woocommerce_integration_nettix_cron_hook' );
	}

	register_deactivation_hook( __FILE__, 'woocommerce_integration_nettix_deactivate' );
}

function woocommerce_integration_nettix_activate() {
	$plugin_path = trailingslashit( WP_PLUGIN_DIR ) . 'woocommerce/woocommerce.php';
	if (
		in_array( $plugin_path, wp_get_active_and_valid_plugins() )
		|| in_array( $plugin_path,
			wp_get_active_network_plugins() )
	) {
		$activation = new Activation();
		$activation->do_activation();
	    if ( ! wp_next_scheduled( 'woocommerce_integration_nettix_cron_hook' ) ) {
		    wp_schedule_event( time(), 'hourly', 'woocommerce_integration_nettix_cron_hook' );
	    }
	} else {
		error_log("Could not activate Integration to NettiX for WooCommerce because WooCommerce plugin is not activated");
	}
}
register_activation_hook( __FILE__, 'woocommerce_integration_nettix_activate' );

function wc_integration_to_nettix_show_wc_not_activated_notice() {
	$plugin_path = trailingslashit( WP_PLUGIN_DIR ) . 'woocommerce/woocommerce.php';

	if (
		!in_array( $plugin_path, wp_get_active_and_valid_plugins() )
		&& !in_array( $plugin_path, wp_get_active_network_plugins() )
	) {
		echo'<div class="notice notice-error is-dismissible"><p><strong>Integration to NettiX for WooCommerce</strong> needs WooCommerce to be activated. After WooCommerce activation reactivate Integration to NettiX for WooCommerce.</p></div>';
	}
}
add_action('admin_notices', 'wc_integration_to_nettix_show_wc_not_activated_notice');